==========================
DPGEN's documentation
==========================

.. _tutorial:

.. toctree::
   :maxdepth: 2
   :caption: Tutorial
   :glob:  

   toymodels/*


.. _Contribution:

.. toctree::
   :maxdepth: 2
   :caption: Contribution Guild

   README.md

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _feedback: 
.. _affiliated packages: 
